@@ -13,7 +13,8 @@ import requests
 import json
 
 
-import constantes as myConst 
+import nklAPI_Datas as nklD
+import nklAPI_Collections as nklC
 
 
 
@@ -21,29 +22,7 @@ def collectionToDf(nklTarget, targetCollection):
     
     
     # TODO
-    
-    listColumn = []
-    
-    url = myConst.API_URL+"/collections/"+targetCollection
-    APIheaders = {"X-API-KEY": nklTarget.API_KEY_NKL} 
-    
-    try : 
-        
-        response = requests.get(url, headers=APIheaders)
-        if response.status_code == 200:
-            
-            dicoR = json.loads(response.text)
-            
-            print(dicoR)
-            
-            listMetas = dicoR['metas']
-            for meta in listMetas:
-                
-                print("propertyUri : ", meta["propertyUri"])
-            
-    except :
-          e = sys.exc_info()[0]
-          print("error ", e)
+    pass
     
 
 def collectionDatasToDf(nklTarget, targetCollection):
@@ -88,99 +67,95 @@ def collectionDatasToDf(nklTarget, targetCollection):
 
     while indexPage <= lastPage:
         
-    
-        url = nklTarget.API_URL+"/collections/"+targetCollection+"/datas?page="+str(indexPage)+"&limit=10"
         
-        APIheaders = {}
-        if nklTarget.apiKey_isEmpty()==False:
-            APIheaders = {"X-API-KEY": nklTarget.API_KEY_NKL}  
         
-                
-        try : 
+        rc = nklC.get_collections_datas(nklTarget, targetCollection, page=indexPage, limit=10)
+        indexPage+=1
+        
+        if rc.isSuccess:
+            lastPage = rc.dictVals['lastPage']
             
-            print(url)
-            response = requests.get(url, headers=APIheaders)
+            print("pagined extraction:", str(indexPage-1)+"/"+str(lastPage))
+
             
-            if response.status_code == 200:
+            for data in rc.dictVals['data']:
+
+                dataUri = data["uri"]
+                dataUri = dataUri.replace('https://doi.org/','')
                 
-                dicoR = json.loads(response.text)
+                print(dataUri,' ', data["status"])
                 
-                lastPage = dicoR['lastPage']
-            
-                print(dicoR['currentPage'], " / ", dicoR['lastPage'])
-                indexPage +=1
+                dataTitle = ""
                 
-                for data in dicoR['data']:
-                    dataUri = data["uri"]
-                    dataUri = dataUri.replace('https://doi.org/','')
+                dicRowData = {}
+                dicRowData['dataIdentifier'] = dataUri
+                dicRowData['uriData'] = nklTarget.BASE_URL+"/"+dataUri
+                dicRowData['linkedInCollection'] = "not yet available in nakalapycon"
+                
+                if 'collectionsIds' in data:
+                    print(data["collectionsIds"])
+                
+                dicRowData['creators_formated'] = ""
+                
+                for meta in data['metas']:
+                    #print(meta['value'], " ", meta['propertyUri'])
                     
-                    print(dataUri,' ', data["status"])
-                    
-                    dataTitle = ""
-                    
-                    dicRowData = {}
-                    dicRowData['dataIdentifier'] = dataUri
-                    dicRowData['uriData'] = nklTarget.BASE_URL+"/"+dataUri
-                    dicRowData['linkedInCollection'] = "not yet available in nakalapycon"
-                    
-                     
-                    if 'collectionsIds' in data:
-                        print(data["collectionsIds"])
-                    
-                    dicRowData['creators_formated'] = ""
-                    
-                    for meta in data['metas']:
-                        #print(meta['value'], " ", meta['propertyUri'])
+                    if meta['propertyUri'] == 'http://nakala.fr/terms#title':
+                        #print("title :", meta['value'])
+                        dataTitle = meta['value']
+                        dicRowData['nkl_title'] = dataTitle
+                      
+                    if meta['propertyUri'] == 'http://nakala.fr/terms#created':
+                        dicRowData['nkl_created'] = meta['value']
                         
-                        if meta['propertyUri'] == 'http://nakala.fr/terms#title':
-                            #print("title :", meta['value'])
-                            dataTitle = meta['value']
-                            dicRowData['nkl_title'] = dataTitle
-                          
-                        if meta['propertyUri'] == 'http://nakala.fr/terms#created':
-                            dicRowData['nkl_created'] = meta['value']
+                    if meta['propertyUri'] == 'http://nakala.fr/terms#license':
+                        dicRowData['nkl_license'] = meta['value']
+                      
+                    
+                    if meta['propertyUri'] == "http://nakala.fr/terms#type":
+                        dicRowData['nkl_type'] = meta['value']
+                        
+                        #dicRowData['nkl_type_converted'] = myConst.vocabTypeGetKeyByUri(meta['value'])  
+                        dicRowData['nkl_type_converted'] = ""  
+                        
+                    if meta['propertyUri'] == "http://nakala.fr/terms#creator":
+                        
+                        #les anciennes data nakala n'avait pas la meme structuration pour le type creator
+                        if not (meta['value']==None):
                             
-                        if meta['propertyUri'] == 'http://nakala.fr/terms#license':
-                            dicRowData['nkl_license'] = meta['value']
-                          
-                        if meta['propertyUri'] == "http://nakala.fr/terms#type":
-                            #print("type :",myConst.VOCABTYPE_reverse[meta['value']])
-                            dicRowData['nkl_type'] = meta['value']
-                            
-                            dicRowData['nkl_type_converted'] = myConst.vocabTypeGetKeyByUri(meta['value'])  
-                            
-                        if meta['propertyUri'] == "http://nakala.fr/terms#creator":
-                            
-                            formattedName = meta['value']['givenname']+" "+meta['value']['surname']
-                            
-                            if dicRowData['creators_formated'] == "":
-                                dicRowData['creators_formated'] = formattedName
+                            if isinstance(meta['value'], dict):
+                                formattedName = meta['value']['givenname']+" "+meta['value']['surname']
+                                
+                                if dicRowData['creators_formated'] == "":
+                                    dicRowData['creators_formated'] = formattedName
+                                else:
+                                    dicRowData['creators_formated'] += ", "+formattedName
                             else:
-                                dicRowData['creators_formated'] += ", "+formattedName
-                            
-                    dfData = dfData.append(dicRowData, ignore_index=True) 
-                    
-                    for file in data['files']:
-                        #print(file['name'], file['extension'],file['size'],file['mime_type'],file['sha1'],file['embargoed'],file['description'])
-                        #print(">> uriFile", myConst.API_URL+"/data/"+dataUri+"/"+file['sha1'])
-                        dicRowFile = file.copy()
-                        #dicRowFile = {}
-                        dicRowFile['linkedInData'] = dataUri
-                        dicRowFile['linkedInData_Title'] = dataTitle
-                        dicRowFile['uriData'] = nklTarget.BASE_URL+"/"+dataUri
-                        dicRowFile['uriFileDL'] = nklTarget.API_URL+"/data/"+dataUri+"/"+file['sha1']
-                        dicRowFile['uriFileEmbed'] = nklTarget.API_URL+"/embed/"+dataUri+"/"+file['sha1']
+                                if dicRowData['creators_formated'] == "":
+                                    dicRowData['creators_formated'] = meta['value']
+                                else:
+                                    dicRowData['creators_formated'] += ", "+meta['value']
+                                
+                                
                         
-                        dfFile = dfFile.append(dicRowFile, ignore_index=True)
-                        
-            else:
-                lastPage = 0
-                print(str(response))
+                dfData = dfData.append(dicRowData, ignore_index=True) 
                 
-        except :
-            e = sys.exc_info()[0]
-            print("error ", e)
+                for file in data['files']:
+                    #print(file['name'], file['extension'],file['size'],file['mime_type'],file['sha1'],file['embargoed'],file['description'])
+                    #print(">> uriFile", myConst.API_URL+"/data/"+dataUri+"/"+file['sha1'])
+                    dicRowFile = file.copy()
+                    #dicRowFile = {}
+                    dicRowFile['linkedInData'] = dataUri
+                    dicRowFile['linkedInData_Title'] = dataTitle
+                    dicRowFile['uriData'] = nklTarget.BASE_URL+"/"+dataUri
+                    dicRowFile['uriFileDL'] = nklTarget.API_URL+"/data/"+dataUri+"/"+file['sha1']
+                    dicRowFile['uriFileEmbed'] = nklTarget.API_URL+"/embed/"+dataUri+"/"+file['sha1']
+                    
+                    dfFile = dfFile.append(dicRowFile, ignore_index=True)
+                        
+        else:
             lastPage = 0
+
     
     return dfData, dfFile
     
